tensors_connect

Function tensors_connect 

pub fn tensors_connect(
    producer: &KernelPattern,
    consumer: &KernelPattern,
) -> bool
Returns true if any output tensor name of producer matches any input tensor name of consumer, indicating data flows between them.