pub fn tensors_connect(
producer: &KernelPattern,
consumer: &KernelPattern,
) -> boolExpand description
Returns true if any output tensor name of producer matches any input
tensor name of consumer, indicating data flows between them.
pub fn tensors_connect(
producer: &KernelPattern,
consumer: &KernelPattern,
) -> boolReturns true if any output tensor name of producer matches any input
tensor name of consumer, indicating data flows between them.